@@ -26,8 +26,11 @@ DEFAULT_VERSION = Version(0, 0, 1)
 UNREAL_ENGINE_CONFIG_PROPERTY_PROJECT_VERSION = 'ProjectVersion'
 UNREAL_ENGINE_CONFIG_PROPERTY_ADDITIONAL_PLIST_DATA = 'AdditionalPlistData'
 
-REGEX_PATTERN_PROPERTY = rf'^{UNREAL_ENGINE_CONFIG_PROPERTY_PROJECT_VERSION}\s*=\s*([a-zA-Z0-9\.\-]+)\s*$'
-REGEX_PROPERTY = re.compile(REGEX_PATTERN_PROPERTY)
+REGEX_PATTERN_PROPERTY_PROJECT_VERSION = rf'^{UNREAL_ENGINE_CONFIG_PROPERTY_PROJECT_VERSION}\s*=\s*([a-zA-Z0-9\.\-]+)\s*$'
+REGEX_PATTERN_PROPERTY_ADDITIONAL_PLIST_DATA = rf'^{UNREAL_ENGINE_CONFIG_PROPERTY_ADDITIONAL_PLIST_DATA}\s*=.*$'
+
+REGEX_PROPERTY_PROJECT_VERSION = re.compile(REGEX_PATTERN_PROPERTY_PROJECT_VERSION)
+REGEX_PROPERTY_ADDITIONAL_PLIST_DATA =re.compile(REGEX_PATTERN_PROPERTY_ADDITIONAL_PLIST_DATA)
 
 
 def read_project_version(
@@ -106,7 +109,7 @@ def read_project_version(
         lines = fd.readlines()
 
     for line in lines:
-        regex_match = REGEX_PROPERTY.match(line.strip())
+        regex_match = REGEX_PROPERTY_PROJECT_VERSION.match(line.strip())
         if regex_match:
             project_version = regex_match.group(1)
 
@@ -157,7 +160,7 @@ def update_ios_version(
     is_additional_plist_data_property_defined = False
 
     for i in range(len(lines)):
-        regex_match = REGEX_PROPERTY.match(lines[i].strip())
+        regex_match = REGEX_PROPERTY_ADDITIONAL_PLIST_DATA.match(lines[i].strip())
         if regex_match:
             lines[i] = f'{UNREAL_ENGINE_CONFIG_PROPERTY_ADDITIONAL_PLIST_DATA}={version.plist_data}'
             is_additional_plist_data_property_defined = True
@@ -202,7 +205,7 @@ def update_project_version(
     is_project_version_property_defined = False
 
     for i in range(len(lines)):
-        regex_match = REGEX_PROPERTY.match(lines[i].strip())
+        regex_match = REGEX_PROPERTY_PROJECT_VERSION.match(lines[i].strip())
         if regex_match:
             lines[i] = f'{UNREAL_ENGINE_CONFIG_PROPERTY_PROJECT_VERSION}={version}'
             is_project_version_property_defined = True
